firstResultFormat = {
    "type": "type of the analyzed file, for example, Component, Service, Guard, etc.",
    "selector": "if the type of the analyzed file is a Componet, this field should contain its selector string from its class decorator. \
        If the file is not a Component, the value should be an empty string",
    "name": "name of the class in the analyzed file, for example AppComponent, LoginService, etc.",
    "file": "the name of the analyzed file. If you received multiple files for a component - the .ts and the .html, this should be the name of the .ts file",
    "path": "the path of the component - if there is any - from the navigation modules. In this step, the value of this should remain an empty list",
    "guarded": "if the class is a component, and it is protected by an AuthGuard, the value should be 1, the default value is 0",
    "guardLevel": "The value of this should be 0",
    "guards": "The names of the guard classes that protect the class in the analyzed file. The default value is an empty list []. If the analyzed class is not an Angular Component, it must remain an empty list.",
    "navigations": "A list of possible navigations from the file by class names. If you cannot find out the class name of the component \
         targeted by the navigation, you should include it's path. An optimal value of this field would be: ['LoginComponent', 'DashboardComponent'] \
        an acceptable value would be ['/login', '/dashboard']. If there are no possible navigations from the analyzed class, the list should be empty.\
        You also need to take into account navigations that can possibly happen via a service, such as this.superService.navigate('home') or this.tereloService.menj('/profile')\
        If the analyzed file was an Angular Module, the value should be an empty list ([])!",
    "injections": "A dict, where the keys are the names of the services and other injectables that were injected into the analyzed class via \
        the constructor. The values of the keys is a dict, containing and organizing the calls when said injectable was used in the file. The keys of this inner dict are \
        Asynchrons, Functions and Variables. Asynchron refers to Promises and Observables used by the analyzed file, Functions to the names of functions called \
        by the analyzed file, Variables to the various variables of the injected accessed directly by the analyzed file. \
         The values of this inner dict are lists which are either empty, if that type of interaction with the \
        injectable did not happen, or the names of said interaction.  \
        An example value for this field would be: \{'LoginService': {'Functions': ['login', 'forgotPassword'], 'Variables': [], 'Asynchrons: ['currentUser']'}, 'LoggerService: {'Functions': ['logInfo', 'logError'], 'Variables': ['log'], 'Asynchrons': []}'\} \
        If there are no injectables in the file, the value should be an empty dict!",
    "parents": "If the analyzed file is a Component and it has parent Components, this should be a list that contains the names of \
        those components, like ['ProfileComponent'], or ['LoginComponent', 'RegisterComponent']. The default value is an empty list.",
    "children": "If the type of the analyzed file is a Component, this list should contain the names - or if the names cannot be determined from \
        the context, then the selector strings of every child Component that are contained by the HTML template of the Component. \
        For example: ['SpinnerComponent', 'alert-component']. If the type \
        of the file is not Component or it doesn't have any children, then the value of this field should be an empty list. The \
        router-outlet should also be considered to be a child, so if the .html template contains it, it should be included here!"
}

firstResultFormatExample = {
    "type": "Component",
    "selector": "profile-comp",
    "name": "ProfileComponent",
    "file": "profile.component.ts",
    "path": ["/profile"],
    "guarded": 0,
    "guards": [],
    "guardLevel": 0,
    "navigations": ['/dashboard'],
    "injections": {'OAuthService': {'Functions': ['checkAuth'], 'Variables': [], 'Asynchrons': ['token']}, 'LoggerService': {'Function': ['logInfo', 'logError'], 'Variable': ['log'], 'Asynchron': []}},
    "parents": [],
    "children": []
}

def firstPrompt(section: str):
    prompt = """
    You will receive a minified version of a TypeScript file from an Angular web application, separated by three backticks,
    describing either a Module, a Component, a Service, a Guard or an Interceptor of an Angular project. 
    If the file contains a Component, and the template of the Component
    is stored in a separate .html file, the contents of that .html file will also be included, meaning that you will receive two minified
    files instead of one.
    Your goal is to create JSON from said file, which contains the services that were injected into it via the constructor, the names of
    the functions called from said services, the possible navigation operations,
    and in case of components, the names of the children components in a list. If any of the mentioned elements are missing, its place
    in the JSON should contain the key, but only an empty list as its value.
    The JSON should follow this format:
    {firstResultFormat}
    A short example of a correct output:
    {firstResultFormatExample}
    The file to be analyzed is the following:
    ```
    {section}
    ```
    Your answer should only contain the JSON and nothing else, as your answer will be instantly parsed as a JSON by the receiver!
    Use double quotation marks (") and no single quotation mark (') under any circumstance!
    """

    return prompt.format(section=section, firstResultFormat=firstResultFormat, firstResultFormatExample=firstResultFormatExample)

def secondPrompt(firstResult, filteredGuards):
    prompt = ''' 
    You will receive a JSON object, which is describing a Component from
    an Angular project and their relations to each other. The JSON object will follow this format:
    {firstResultFormat}
    With this JSON you will also receive minified versions of the Angular files, that will contain information concerning
    the routing and the authguard configurations of the web application.
    Based on these files you will need to extend the JSON representing the Component with the following steps.
    1. Modify the path value if their 'path' is an empty list. 
    If there is no path defined in any of the Route[] arrays in the received files that contain a path value for that particular Component, then the value of its path should
    remain an empty list in the JSON. There is a good chance for example, that Components that are children to another Component should not have
    any paths, because they are most likely to be accessible through their parent Component.
    For example: 
    If there is {{ path: 'register', component: RegisterComponent }} in one of the routing modules
    Then in the JSON, where type: 'Component' and name: 'RegisterComponent', 'path' should be ['/register']
    Make sure that even if there's already a value in the path field, it has a unified format, such as '/register', '/home', '/profile/:id'
    The reason why the path is a list and not a string is because you also need to include the default/home path to the appropriate JSON ('/') and
    the wildcard path ('**') to the appropriate JSON if they exist in the route definitions.
    The paths might be also stored in multiple files if there is a module-submodule relationship. For example, if one routing module contains the following:
    {{path: 'users/:id',loadChildren: () => import("./users-module/users.module").then(m => m.UsersModule)}},
    then the UsersModule imports another routing module, for example a UsersRoutingModule, where there is a line such as:
    {{path: 'addition', component: AddUserComponent}},
    then the path for the AddUserComponent is '/users/:id/adddition'
    if there is {{path: '', redirectTo: 'profile'}} in that module, then the component with the 
    '/users/:id/profile' path should also get the '/users/:id/' route in their paths array.
    Do not under any circumstance mix the paths and the possible navigations from that given Component!
    - only Components have paths!
    - most Component only have one path. If the Component is used as the child Component of another, it is very likely that it doesn't have a path
    in the routing information, therefore its path list should remain empty.
    - the only exceptions are usually the default routes: '', '/' and the wildcard route: '**'
    - be very precise, do not include false or faulty paths!
    2. List every 'Guard' by their class names in the 'guards' list of the JSON that are protecting the Component based on the canActivate parts of
    the routing information.
    For example:
    if there is a configuration like this in one of the module files {{path: 'profile', component: ProfileComponent, canActivate: [AuthguardGuard]}}
    then in the JSON, where 'type': 'Component' and 'name': 'ProfileComponent', 'guarded' should be set to 1, and the 'guards' should be: ['AuthguardGuard']
    Again, take into account the module level imports: if there is a 
    {{path: 'users/:id', canActivate: [RoleGuard], loadChildren: () => import("./users-module/users.module").then(m => m.UsersModule)}}
    then every route/component that is imported by the UsersModule already has the RoleGuard, in addition to any other they might have individually!
    for example a {{path: 'addition', component: AddUserComponent}} in the UsersModule's imported routes would give the AddUserComponent's JSON the ['RoleGuard'] as its guard, 
    while a {{path: 'deletion', component: DeletionUserComponent, canActivate: [AdminGuard]}} would give the DeletionUserComponent's JSON
    the ['RoleGuard', 'AdminGuard'] list as its 'guards'.
    3. As a final step, you need to calculate the guardLevel if the JSON has 'Component' as its type, based on the following rules:
    - if the 'guarded' value is 0 and their 'guards' list is still empty after the previous steps, the 'guardLevel' is 0
    - if it has at least one Guard in their 'guards' list, but based on the implementation of it, that Guard only checks whether the user is logged in
    in or not, the 'guardLevel' should be 1.
    - if the implementation of Guard or Guards in the 'guards' list not only check whether they are logged in, but they also check for access level - admin
    or normal user; patient, relative, nurse or practitioner; buyer or seller - the 'guardLevel' should be 2.
    - if the implementation of the Guards contain everything necessary for guardLevel 2, but go beyond them and check for extra information, for example, location,
    IP address, timezone, device/browser type, the guardLevel should be 3.
    Your answer should contain the full version of the modified JSON list, it will have to include every object which was
    in the input and contain every modification you have made to them. The answer should only contain this list, because it will be
    parsed as a JSON object in its entirety.
    If the project does not contain any routing or guard information, then your answer should be the JSON list without any modifications.
    This is the input JSON list, separated by three backticks:
    ```
    {firstResult}
    ```
    And these are the minified files containing the routing and guard information, also separated by three backticks:
    ```
    {filteredGuards}
    ```
    '''
    return prompt.format(firstResultFormat=firstResultFormat, firstResult=firstResult, filteredGuards=filteredGuards)
