import os
import json
import pandas as pd

# Create the evaluations directory if it does not exist
if not os.path.exists('evaluations'):
    os.makedirs('evaluations')

# Specify the path to the directory where your JSON files are located
json_folder_path = os.path.join('tmp')

# Get all JSON files in the directory
json_files = [f for f in os.listdir(json_folder_path) if f.endswith('_secondResults_formatted.json')]

# Define a function to process a single JSON file
def process_json_file(json_file_path):
    # Load the JSON file
    with open(json_file_path, 'r') as f:
        data = json.load(f)

    # Filter data for entries where 'type' is 'Component'
    data = [entry for entry in data if entry.get('type') == 'Component']

    # Convert the filtered data into a DataFrame
    df = pd.DataFrame(data)

    # Extract the needed fields and format them as required
    df['ComponentName'] = df['name']
    df['AuthGuards'] = df['guards'].apply(lambda x: ','.join(x) if x else '')
    df['GuardLevel'] = df['guardLevel']
    df['Services'] = df['injections'].apply(lambda x: ','.join(x.keys()))

    # Select the needed columns
    df = df[['ComponentName', 'AuthGuards', 'GuardLevel', 'Services']]

    return df

# Create an Excel writer object
writer = pd.ExcelWriter(os.path.join('evaluations', 'component-results.xlsx'), engine='openpyxl')

# Process each JSON file and write its data to a separate sheet in the Excel file
for json_file in json_files:
    df = process_json_file(os.path.join(json_folder_path, json_file))
    df.to_excel(writer, index=False, sheet_name=json_file.replace('_secondResults_formatted.json', ''))

# Save the Excel file
writer.save()
