import pandas as pd
import os

# Read the xlsx files
xls1 = pd.ExcelFile(os.path.join('evaluations', 'component-results.xlsx'))
xls2 = pd.ExcelFile(os.path.join('evaluations', 'sensitive-services.xlsx'))

# Create a writer for the new xlsx file
writer = pd.ExcelWriter(os.path.join('evaluations', 'security-alerts.xlsx'), engine='xlsxwriter')

# Loop over the sheets in the first file
for sheet_name in xls1.sheet_names:
    df1 = pd.read_excel(xls1, sheet_name=sheet_name)

    # Find the matching sheet in the second file
    matching_sheet_name = next((name for name in xls2.sheet_names if name[:20] == sheet_name[:20]), None)

    if matching_sheet_name is not None:
        df2 = pd.read_excel(xls2, sheet_name=matching_sheet_name)
    else:
        print(f"No matching sheet found for {sheet_name}")
        continue

    # Initialize new columns
    df1['SensitiveServices'] = ''
    df1['SensitivityLevel'] = 0

    # Loop through df1 and fill the new columns
    for i, row in df1.iterrows():
        matching_rows = df2[df2['Classname'] == row['ComponentName']]
        if not matching_rows.empty:
            df1.at[i, 'SensitiveServices'] = ';'.join(matching_rows['ServiceName'].dropna().astype(str))
            df1.at[i, 'SensitivityLevel'] = matching_rows['Level'].max()

    # Calculate the Alert column
    df1['Alert'] = (df1['SensitivityLevel'] > df1['GuardLevel']).astype(int)

    # Write to the new xlsx file
    df1.to_excel(writer, sheet_name=sheet_name[:20], index=False)

# Save the new xlsx file
writer.save()
